==> taler-wallet-v0.13.1.tar.gz: taler-wallet-v0.13.1/packages/merchant-backoffice-ui/src/paths/instance/products/list/index.tsx <==
/*
 This file is part of GNU Taler
 (C) 2021-2024 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import {
  HttpStatusCode,
  TalerError,
  TalerMerchantApi,
  assertUnreachable,
} from "@gnu-taler/taler-util";
import { useTranslationContext } from "@gnu-taler/web-util/browser";
import { VNode, h } from "preact";
import { useState } from "preact/hooks";
import { ErrorLoadingMerchant } from "../../../../components/ErrorLoadingMerchant.js";
import { Loading } from "../../../../components/exception/loading.js";
import { JumpToElementById } from "../../../../components/form/JumpToElementById.js";
import { NotificationCard } from "../../../../components/menu/index.js";
import { ConfirmModal } from "../../../../components/modal/index.js";
import { useSessionContext } from "../../../../context/session.js";
import { useInstanceProducts } from "../../../../hooks/product.js";
import { Notification } from "../../../../utils/types.js";
import { LoginPage } from "../../../login/index.js";
import { NotFoundPageOrAdminCreate } from "../../../notfound/index.js";
import { CardTable } from "./Table.js";
import { WithId } from "../../../../declaration.js";

interface Props {
  onCreate: () => void;
  onSelect: (id: string) => void;
}
export default function ProductList({ onCreate, onSelect }: Props): VNode {
  const result = useInstanceProducts();
  const { state, lib } = useSessionContext();
  const [deleting, setDeleting] = useState<
    (TalerMerchantApi.ProductDetail & WithId) | null
  >(null);
  const [notif, setNotif] = useState<Notification | undefined>(undefined);

  const { i18n } = useTranslationContext();

  if (!result) return <Loading />;
  if (result instanceof TalerError) {
    return <ErrorLoadingMerchant error={result} />;
  }
  if (result.type === "fail") {
    switch (result.case) {
      case HttpStatusCode.NotFound: {
        return <NotFoundPageOrAdminCreate />;
      }
      case HttpStatusCode.Unauthorized: {
        return <LoginPage />;
      }
      default: {
        assertUnreachable(result);
      }
    }
  }

  return (
    <section class="section is-main-section">
      <NotificationCard notification={notif} />

      <JumpToElementById
        testIfExist={async (id) => {
          const resp = await lib.instance.getProductDetails(state.token, id);
          return resp.type === "ok";
        }}
        onSelect={onSelect}
        description={i18n.str`Jump to product with the given product ID`}
        placeholder={i18n.str`Product id`}
      />

      <CardTable
        instances={result.body}
        onLoadMoreBefore={result.isFirstPage ? undefined : result.loadFirst}
        onLoadMoreAfter={result.isLastPage ? undefined : result.loadNext}
        onCreate={onCreate}
        onUpdate={async (id, prod) => {
          try {
            const resp = await lib.instance.updateProduct(
              state.token,
              id,
              prod,
            );
            if (resp.type === "ok") {
              setNotif({
                message: i18n.str`Product updated successfully`,
                type: "SUCCESS",
              });
            } else {
              setNotif({
                message: i18n.str`Could not update the product`,
                type: "ERROR",
                description: resp.detail.hint,
              });
            }
          } catch (error) {
            setNotif({
              message: i18n.str`Could not update the product`,
              type: "ERROR",
              description: error instanceof Error ? error.message : undefined,
            });
          }
          return;
        }}
        onSelect={(product) => onSelect(product.id)}
        onDelete={(prod: TalerMerchantApi.ProductDetail & WithId) =>
          setDeleting(prod)
        }
      />

      {deleting && (
        <ConfirmModal
          label={`Delete product`}
          description={`Delete the product "${deleting.description}"`}
          danger
          active
          onCancel={() => setDeleting(null)}
          onConfirm={async (): Promise<void> => {
            try {
              const resp = await lib.instance.deleteProduct(
                state.token,
                deleting.id,
              );
              if (resp.type === "ok") {
                setNotif({
                  message: i18n.str`Product "${deleting.description}" (ID: ${deleting.id}) has been deleted`,
                  type: "SUCCESS",
                });
              } else {
                setNotif({
                  message: i18n.str`Could not delete the product`,
                  type: "ERROR",
                  description: resp.detail.hint,
                });
              }
            } catch (error) {
              setNotif({
                message: i18n.str`Could not delete the product`,
                type: "ERROR",
                description: error instanceof Error ? error.message : undefined,
              });
            }
            setDeleting(null);
          }}
        >
          <p>
            <i18n.Translate>
              If you delete the product named{" "}
              <b>&quot;{deleting.description}&quot;</b> (ID:{" "}
              <b>{deleting.id}</b>
              ), the stock and related information will be lost
            </i18n.Translate>
          </p>
          <p class="warning">
            <i18n.Translate>
              Deleting an product can't be undone.
            </i18n.Translate>
          </p>
        </ConfirmModal>
      )}
    </section>
  );
}

==> taler-wallet-v1.1.0.tar.gz: taler-wallet-v1.1.0/packages/merchant-backoffice-ui/src/paths/instance/products/list/index.tsx <==
/*
 This file is part of GNU Taler
 (C) 2021-2024 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import {
  HttpStatusCode,
  TalerError,
  TalerMerchantApi,
  assertUnreachable,
} from "@gnu-taler/taler-util";
import { useTranslationContext } from "@gnu-taler/web-util/browser";
import { VNode, h } from "preact";
import { useState } from "preact/hooks";
import { ErrorLoadingMerchant } from "../../../../components/ErrorLoadingMerchant.js";
import { Loading } from "../../../../components/exception/loading.js";
import { JumpToElementById } from "../../../../components/form/JumpToElementById.js";
import { NotificationCard } from "../../../../components/menu/index.js";
import { ConfirmModal } from "../../../../components/modal/index.js";
import { useSessionContext } from "../../../../context/session.js";
import { useInstanceProducts } from "../../../../hooks/product.js";
import { Notification } from "../../../../utils/types.js";
import { LoginPage } from "../../../login/index.js";
import { NotFoundPageOrAdminCreate } from "../../../notfound/index.js";
import { CardTable } from "./Table.js";
import { WithId } from "../../../../declaration.js";

interface Props {
  onCreate: undefined | (() => void);
  onSelect: (id: string) => void;
}
export default function ProductList({ onCreate, onSelect }: Props): VNode {
  const result = useInstanceProducts();
  const { state, lib } = useSessionContext();
  const [deleting, setDeleting] = useState<
    (TalerMerchantApi.ProductDetail & WithId) | null
  >(null);
  const [notif, setNotif] = useState<Notification | undefined>(undefined);

  const { i18n } = useTranslationContext();

  if (!result) return <Loading />;
  if (result instanceof TalerError) {
    return <ErrorLoadingMerchant error={result} />;
  }
  if (result.type === "fail") {
    switch (result.case) {
      case HttpStatusCode.NotFound: {
        return <NotFoundPageOrAdminCreate />;
      }
      case HttpStatusCode.Unauthorized: {
        return <LoginPage />;
      }
      default: {
        assertUnreachable(result);
      }
    }
  }

  return (
    <section class="section is-main-section">
      <NotificationCard notification={notif} />

      <JumpToElementById
        testIfExist={async (id) => {
          const resp = await lib.instance.getProductDetails(state.token, id);
          return resp.type === "ok";
        }}
        onSelect={onSelect}
        description={i18n.str`Jump to product with the given product ID`}
        placeholder={i18n.str`Product id`}
      />

      <CardTable
        instances={result.body}
        onLoadMoreBefore={result.loadFirst}
        onLoadMoreAfter={result.loadNext}
        onCreate={onCreate}
        onUpdate={async (id, prod) => {
          try {
            const resp = await lib.instance.updateProduct(
              state.token,
              id,
              prod,
            );
            if (resp.type === "ok") {
              setNotif({
                message: i18n.str`Product updated successfully`,
                type: "SUCCESS",
              });
            } else {
              setNotif({
                message: i18n.str`Could not update the product`,
                type: "ERROR",
                description: resp.detail?.hint,
              });
            }
          } catch (error) {
            setNotif({
              message: i18n.str`Could not update the product`,
              type: "ERROR",
              description: error instanceof Error ? error.message : undefined,
            });
          }
          return;
        }}
        onSelect={(product) => onSelect(product.id)}
        onDelete={(prod: TalerMerchantApi.ProductDetail & WithId) =>
          setDeleting(prod)
        }
      />

      {deleting && (
        <ConfirmModal
          label={`Delete product`}
          description={`Delete the product "${deleting.description}"`}
          danger
          active
          onCancel={() => setDeleting(null)}
          onConfirm={async (): Promise<void> => {
            try {
              const resp = await lib.instance.deleteProduct(
                state.token,
                deleting.id,
              );
              if (resp.type === "ok") {
                setNotif({
                  message: i18n.str`Product "${deleting.description}" (ID: ${deleting.id}) has been deleted`,
                  type: "SUCCESS",
                });
              } else {
                setNotif({
                  message: i18n.str`Could not delete the product`,
                  type: "ERROR",
                  description: resp.detail?.hint,
                });
              }
            } catch (error) {
              setNotif({
                message: i18n.str`Could not delete the product`,
                type: "ERROR",
                description: error instanceof Error ? error.message : undefined,
              });
            }
            setDeleting(null);
          }}
        >
          <p>
            <i18n.Translate>
              If you delete the product named{" "}
              <b>&quot;{deleting.description}&quot;</b> (ID:{" "}
              <b>{deleting.id}</b>
              ), the stock and related information will be lost
            </i18n.Translate>
          </p>
          <p class="warning">
            <i18n.Translate>
              Deleting a product cannot be undone.
            </i18n.Translate>
          </p>
        </ConfirmModal>
      )}
    </section>
  );
}
